import QtQuick 1.0

Flipable {
    id: card
    state: "back"
    property bool flipped: false
    property int face: 9
    property int background: 0

    signal selected

    front: Image {
        source: "background_" + background + ".png"
        smooth: true
    }
    width:  front.width
    height: front.height

    back: Rectangle {
        color: "white"
        anchors.fill: parent
        smooth: true
        radius: 8

        Image {
            id: faceImage
            source: "image_" + card.face + ".png"
            smooth: true
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
        }
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: {
            if (!card.flipped) {
                card.flipped = true; card.selected()
            }
        }
    }

    transform: Rotation {
        id: rotation
        origin.x: card.width/2
        origin.y: card.height/2
        axis.x: 0; axis.y: 1; axis.z: 0
        angle: 0
    }

    states: State {
        name: "back"
        when: card.flipped
        PropertyChanges {
            target: rotation; angle: 180
        }
    }

    transitions: Transition {
        ParallelAnimation {
            NumberAnimation {target: rotation; property: "angle"; duration: 300}
            SequentialAnimation {
                NumberAnimation {target: card; property: "scale"; from: 1; to: 0.75; duration: 150}
                NumberAnimation {target: card; property: "scale"; from: 0.75; to: 1; duration: 150}
            }
        }
    }
}
